@@ -426,7 +426,7 @@ class TableWriter(object):
             raise ValueError(f"Tex file {self.__path} not found.")
 
         path_to_compile = self.__path
-        if self.__path.fs_kind == "gcs":
+        if "gcs" in self.__path.fs_kind:
             path_to_compile = tempfile.NamedTemporaryFile(delete=False, suffix=".tex")
             path_to_compile.close()
             self.__path.get(path_to_compile.name)
@@ -449,13 +449,10 @@ class TableWriter(object):
         time.sleep(0.5)
         x3 = os.system(command)
 
-        if self.__path.fs_kind == "gcs":
+        if "gcs" in self.__path.fs_kind:
             glob_in = path_to_compile.parent
-            print("path_to_compile", path_to_compile)
             for path in glob_in.glob(f"{path_to_compile.stem}*"):
                 path_gcs = self.__path.with_suffix(path.suffix)
-                print("  path", path)
-                print("  path_gcs", path_gcs)
                 path.put(path_gcs)
                 path.rm()
 
